removed extra LOC from javadoc whilst I was there - no warnings about the whole cvslib now!! (have to make teh compiler even more strict ;) )


Index: ChangeLogParser.java
===================================================================
RCS file: 
/home/cvspublic/ant/src/main/org/apache/tools/ant/taskdefs/cvslib/ChangeLogParser.java,v
retrieving revision 1.28
diff -u -r1.28 ChangeLogParser.java
--- ChangeLogParser.java        6 Dec 2004 17:35:42 -0000       1.28
+++ ChangeLogParser.java        17 Dec 2004 03:19:53 -0000
@@ -28,7 +28,7 @@
  *
  * @version $Revision: 1.28 $ $Date: 2004/12/06 17:35:42 $
  */
-class ChangeLogParser {
+public class ChangeLogParser {
     //private static final int GET_ENTRY = 0;
     private static final int GET_FILE = 1;
     private static final int GET_DATE = 2;
@@ -60,7 +60,6 @@
 
     /**
      * Get a list of rcs entries as an array.
-     *
      * @return a list of rcs entries as an array
      */
     public CVSEntry[] getEntrySetAsArray() {
@@ -110,7 +109,6 @@
 
     /**
      * Process a line while in "GET_COMMENT" state.
-     *
      * @param line the line
      */
     private void processComment(final String line) {
@@ -136,7 +134,6 @@
 
     /**
      * Process a line while in "GET_FILE" state.
-     *
      * @param line the line to process
      */
     private void processFile(final String line) {
@@ -148,7 +145,6 @@
 
     /**
      * Process a line while in "REVISION" state.
-     *
      * @param line the line to process
      */
     private void processRevision(final String line) {
@@ -183,7 +179,6 @@
 
     /**
      * Process a line while in "GET_PREVIOUS_REVISION" state.
-     *
      * @param line the line to process
      */
     private void processGetPreviousRevision(final String line) {
@@ -217,13 +212,12 @@
 
     /**
      * Parse date out from expected format.
      *
      * @param date the string holding date
      * @return the date object or null if unknown date format
      */
-    private Date parseDate(final String date) {
+    private Date parseDate(final String pDate) {
         try {
-            return INPUT_DATE.parse(date);
+            return INPUT_DATE.parse(pDate);
         } catch (ParseException e) {
             //final String message = REZ.getString( 
"changelog.bat-date.error", date );
             //getContext().error( message );

---------------------------------------------------------------------
@@ -217,13 +212,12 @@
     /**
      * Parse date out from expected format.
-     *
-     * @param date the string holding date
+     * @param pDate the string holding date
      * @return the date object or null if unknown date format
      */
To unsubscribe, e-mail: [EMAIL PROTECTED]
For additional commands, e-mail: [EMAIL PROTECTED]

Reply via email to